@@ -19,7 +19,7 @@ use Encode 'encode', 'decode';
 
 use Carp 'confess';
 
-our $VERSION = '0.0704';
+our $VERSION = '0.0705';
 
 my $SPVM_ENV;
 my $BUILDER;
@@ -289,6 +289,8 @@ Currently some ports of document are use Automatic translation, so not accurate
 
 =item * L<SPVM Native API|https://yuki-kimoto.github.io/spvmdoc-public/native-api.html>
 
+=item * L<SPVM Performance Benchmark|https://yuki-kimoto.github.io/spvmdoc-public/benchmark.html>
+
 =head1 CORE MODULES
 
 SPVM Core Modules.
@@ -429,11 +431,23 @@ SPVM Core Modules.
 
 =back
 
-=head1 EXAMPLES
+=head1 GETTING STARTED
 
-=head2 How to write SPVM and Call it from Perl
+Get started with SPVM.
 
-SPVM Module:
+At first I will explain how to write for statement in SPVM.
+
+Next, I will explain how to precompile SPVM subroutines so that they run at the same speed as in machine language.
+
+Finally, I will explain how to write SPVM subroutines biding C language.
+
+If you are interested in the SPVM tutorial, see SPVM Tutorial.
+
+L<SPVM Tutorial|https://yuki-kimoto.github.io/spvmdoc-public/tutorial.html>
+
+=head2 How to write SPVM language
+
+This is a simple example using the SPVM for statement.
 
   # lib/MyMath.spvm
   package MyMath {
@@ -448,7 +462,77 @@ SPVM Module:
     }
   }
 
-Use SPVM Module from Perl
+You create "lib" direcotry and create "MyMath.spvm" file.
+
+The extension of SPVM is ".spvm".
+
+SPVM need package definition.
+
+  package MyMath {
+
+  }
+
+See SPVM subroutine definition.
+
+  package MyMath {
+    sub sum : int ($nums : int[]) {
+    
+    }
+  }
+
+"int" after subroutine name "sum" is return value type.
+
+"int" is signed 32bit numeric type.
+
+"int[]" is argument type.
+
+"int[]" is array type that element type is "int".
+
+SPVM is static type language. You must specify subroutine return type and argument type.
+
+See subroutine implementation.
+
+    sub sum : int ($nums : int[]) {
+      
+      my $total = 0;
+      for (my $i = 0; $i < @$nums; $i++) {
+        $total += $nums->[$i];
+      }
+      
+      return $total;
+    }
+
+"my" is lexical variable declaration. 
+
+  my $total = 0;
+
+There is no type declaration. Type inference is performed using the value on the right side. Same as the description below.
+
+  my $total :int = 0;
+
+See for loop.
+
+      for (my $i = 0; $i < @$nums; $i++) {
+        $total += $nums->[$i];
+      }
+
+for loop is same as Perl syntax. You can get array length by @. @ is array length operator in all context instead of Perl.
+
+Array access use arrow operator.
+
+  $nums->[$i]
+
+At last, return value.
+
+      return $total;
+
+If you want to know the syntax of SPVM, the SPVM Language Specification has a complete description.
+
+L<SPVM Language Specification|https://yuki-kimoto.github.io/spvmdoc-public/language.html>
+
+=head2 How to call SPVM subroutine from Perl
+
+You may be surprised to know that SPVM subroutines can be called directly from Perl.
   
   use FindBin;
   use lib "$FindBin::Bin/lib";
@@ -460,8 +544,24 @@ Use SPVM Module from Perl
   
   print $total . "\n";
 
+To load an SPVM module from Perl, use the following syntax.
 
-=head2 How to improve performacne using precompile subroutine
+  use SPVM 'MyMath';
+
+Call SPVM subroutine from Perl.
+
+  # Call subroutine
+  my $total = MyMath->sum([3, 6, 8, 9]);
+
+Perl array reference is converted to SPVM int array, and call sum method of MyMath, and SPVM int value of return value is converted to Perl Scalar.
+
+If you want to know the rules for calling SPVM subroutines from Perl, and the rules for converting Perl and SPVM values, see the SPVM Exchagne API.
+
+L<SPVM Exchange API|https://yuki-kimoto.github.io/spvmdoc-public/exchange-api.html>
+
+=head2 How to improve performacne using subroutine precompile
+
+See how to speed up SPVM subroutines. SPVM subroutines can be converted into machine code by precompile descriptor.
 
   # lib/MyMath.spvm
   package MyMath {
@@ -476,12 +576,163 @@ Use SPVM Module from Perl
     }
   }
 
-Precompile
+Subroutine code is same as non precompile subroutine.
 
+A build directory is required to precompile subroutines.
+
+You set SPVM_BUILD_DIR. The following is bash example.
+
+  # ~/.bashrc
   export SPVM_BUILD_DIR=~/.spvm_build
 
+How fast will it be? See SPVM Peformance Benchmark.
+
+L<SPVM Performance Benchmark|https://yuki-kimoto.github.io/spvmdoc-public/benchmark.html>
+
 =head2 How to improve performacne using native subroutine
 
+If you want, you can native subroutine for performance with native descriptor.
+
+  # lib/MyMath.spvm
+  package MyMath {
+    native sub sum_native : int ($nums : int[]);
+  }
+
+Native subrosutine is binding a function of C langage.
+  
+  // lib/MyMath.c
+  #include "spvm_native.h"
+  
+  int32_t SPNATIVE__MyMath__sum_native(SPVM_ENV* env, SPVM_VALUE* stack) {
+    
+    void* sv_nums = stack[0].oval;
+    
+    int32_t length = env->length(env, sv_nums);
+    
+    int32_t* nums = env->get_elems_int(env, sv_nums);
+    
+    int32_t total = 0;
+    for (int32_t i = 0; i < length; i++) {
+      total += nums[i];
+    }
+    
+    stack[0].ival = total;
+    
+    return SPVM_SUCCESS;
+  }
+
+File name is "MyMath.c". 
+
+At first, include "spvm_native.h". This header provide SPVM Native API.
+
+  #include "spvm_native.h"
+
+See the declaration of C function.
+
+  int32_t SPNATIVE__MyMath__sum_native(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+    return SPVM_SUCCESS;
+  }
+
+Return value type is int32_t. The return value indicates that the subroutine did not throw an exception.
+
+SPVM_SUCCESS is macro that value is 0 defined in "spvm_native.h".
+
+C function name start SPNATIVE__. Package name "MyMath" and subroutine name "sum_native" is joined by "__".
+
+If package name contains double colon(Foo::Bar), double colon is replaced by "__".
+
+First argument is a pointer to SPVM_ENV object. This variable has SPVM runtime information.
+
+Second argument is SPVM_VALUE array. stack contains arguments of SPVM subroutine.
+
+And stack is also used to set return value of SPVM subroutine.
+
+See implementation of C function.
+
+  int32_t SPNATIVE__MyMath__sum_native(SPVM_ENV* env, SPVM_VALUE* stack) {
+    
+    void* sv_nums = stack[0].oval;
+    
+    int32_t length = env->length(env, sv_nums);
+    
+    int32_t* nums = env->get_elems_int(env, sv_nums);
+    
+    int32_t total = 0;
+    for (int32_t i = 0; i < length; i++) {
+      total += nums[i];
+    }
+    
+    stack[0].ival = total;
+    
+    return SPVM_SUCCESS;
+  }
+
+At first, get first argument of SPVM subroutine.
+
+    void* sv_nums = stack[0].oval;
+
+"int[]" is array type. array type is also object type. You can get a object by C<oval> field.
+
+Get array length.
+
+    int32_t length = env->length(env, sv_nums);
+
+Get numeric int32_t array of C langage. SPVM int type is same as int32_t type of C language.
+
+    int32_t* nums = env->get_elems_int(env, sv_nums);
+
+Calcuration.
+
+    int32_t total = 0;
+    for (int32_t i = 0; i < length; i++) {
+      total += nums[i];
+    }
+
+At last, set return value to the first element of stack as int type. C<ival> filed is used to get or set int32_t value.
+
+    stack[0].ival = total;
+
+Note that you do not return the SPVM return value with the return keyword of C langauge.
+
+return value of C function indicates whether the subroutine throw an exception.
+
+If you write a native subroutine, you must write a configuration file.
+
+The configuration file for native subroutines is a Perl script.
+
+  # lib/MyMath.config
+
+  use strict;
+  use warnings;
+
+  use SPVM::Builder::Config;
+  my $bconf = SPVM::Builder::Config->new_c99;
+
+  $bconf;
+
+If you write SPVM subroutine using C language, you can use C<new_c99> method of L<SPVM::Builder::Config>.
+
+If you want to see SPVM Native API like length and get_elems_int
+
+    int32_t length = env->length(env, sv_nums);
+    
+    int32_t* nums = env->get_elems_int(env, sv_nums);
+
+See SPVM Native API.
+
+L<SPVM Native API|https://yuki-kimoto.github.io/spvmdoc-public/native-api.html>
+
+A build directory is required to native subroutines.
+
+You set SPVM_BUILD_DIR. The following is bash example.
+
+  # ~/.bashrc
+  export SPVM_BUILD_DIR=~/.spvm_build
+
+How fast will it be? See SPVM Peformance Benchmark.
+
+L<SPVM Performance Benchmark|https://yuki-kimoto.github.io/spvmdoc-public/benchmark.html>
 
 =head1 ENVIRONMENT VARIABLE
 
